@@ -1,8 +1,9 @@
 context("dichotomy.default")
 
+expect_error(as.dichotomy(NULL))
 
 expect_identical(dummy(numeric(0)),
-                 structure(logical(0), .Dim = c(0L, 0L), class = c("dichotomy", 
+                 structure(numeric(0), .Dim = c(0L, 0L), class = c("dichotomy", 
                                                                    "matrix")))
 
 expect_identical(as.dichotomy(numeric(0)),
@@ -11,7 +12,7 @@ structure(list(`NA` = logical(0)), row.names = integer(0), .Names = "NA", class
 
 
 expect_identical(dummy(c(NA,NA,NA)),
-structure(c(NA, NA, NA), .Dim = c(3L, 1L), .Dimnames = list(
+structure(c(NA, NA, NA)*1, .Dim = c(3L, 1L), .Dimnames = list(
  NULL, "NA"), class = c("dichotomy", "matrix")))
 
 expect_identical(as.dichotomy(c(NA,NA,NA)),
@@ -35,6 +36,32 @@ expect_identical(dummy(vec),
                  structure(c(1, 0, 0, 0, 1, 0, 0, 0, 1), .Dim = c(3L, 3L), .Dimnames = list(
                      NULL, c("1", "2", "3")), class = c("dichotomy", "matrix")))
 
+expect_identical(dummy(vec, presence = 5, absence = -5),
+                 structure(c(5, -5, -5, -5, 5, -5, -5, -5, 5), .Dim = c(3L, 3L), .Dimnames = list(
+                     NULL, c("1", "2", "3")), class = c("dichotomy", "matrix")))
+
+expect_identical(dummy(vec, presence = "Y", absence = "N"),
+                 structure(c("Y", "N", "N", "N", "Y", "N", "N", "N", "Y"), .Dim = c(3L, 3L), .Dimnames = list(
+                     NULL, c("1", "2", "3")), class = c("dichotomy", "matrix")))
+
+expect_identical(dummy(vec, presence = FALSE, absence = TRUE),
+                 structure(c(FALSE, TRUE, TRUE, TRUE, FALSE, TRUE, TRUE, TRUE, FALSE), 
+                           .Dim = c(3L, 3L), .Dimnames = list(
+                     NULL, c("1", "2", "3")), class = c("dichotomy", "matrix")))
+
+expect_identical(dummy1(vec, presence = 5, absence = -5),
+                 structure(c(5, -5, -5, -5, 5, -5), .Dim = c(3L, 2L), .Dimnames = list(
+                     NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+
+expect_identical(dummy1(vec, presence = "Y", absence = "N"),
+                 structure(c("Y", "N", "N", "N", "Y", "N"), .Dim = c(3L, 2L), .Dimnames = list(
+                     NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+
+expect_identical(dummy1(vec, presence = FALSE, absence = TRUE),
+                 structure(c(FALSE, TRUE, TRUE, TRUE, FALSE, TRUE), 
+                           .Dim = c(3L, 2L), .Dimnames = list(
+                               NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+
 expect_identical(as.dichotomy(vec),
 structure(list(v1 = structure(c(1, 0, 0), label = "1", class = c("labelled", 
 "numeric")), v2 = structure(c(0, 1, 0), label = "2", class = c("labelled", 
@@ -42,6 +69,21 @@ structure(list(v1 = structure(c(1, 0, 0), label = "1", class = c("labelled",
 "numeric"))), .Names = c("v1", "v2", "v3"), row.names = c(NA, 
                           -3L), class = c("dichotomy", "data.frame")))
 
+expect_identical(as.dichotomy(vec, presence = 5, absence = -5),
+structure(list(v1 = structure(c(5, -5, -5), label = "1", class = c("labelled", 
+"numeric")), v2 = structure(c(-5, 5, -5), label = "2", class = c("labelled", 
+"numeric")), v3 = structure(c(-5, -5, 5), label = "3", class = c("labelled", 
+"numeric"))), .Names = c("v1", "v2", "v3"), row.names = c(NA, 
+  -3L), class = c("dichotomy", "data.frame")))
+
+expect_identical(as.dichotomy(vec, presence = "Y", absence = "N"),
+structure(list(v1 = structure(c("Y", "N", "N"), label = "1", class = c("labelled", 
+"character")), v2 = structure(c("N", "Y", "N"), label = "2", class = c("labelled", 
+"character")), v3 = structure(c("N", "N", "Y"), label = "3", class = c("labelled", 
+"character"))), .Names = c("v1", "v2", "v3"), row.names = c(NA, 
+                            -3L), class = c("dichotomy", "data.frame")))
+
+
 vec = c(1:2,NA)
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
@@ -146,8 +188,10 @@ dep = c(1,1,1,2,2,2)
 indep = c(1,1,3,2,2,3)
 var_lab(indep) = "Label"
 val_lab(indep) = c(a=1,b=2,c=3)
-expect_equal_to_reference(lm(dep ~ dummy(indep)),"rds/lm_dichotomy_default.rds")
-expect_equal_to_reference(lm(dep ~ dummy1(indep)),"rds/lm_dichotomy_default2.rds")
+if(as.numeric(version$major) ==3 && as.numeric(version$minor)<5){
+    expect_equal_to_reference(lm(dep ~ dummy(indep)),"rds/lm_dichotomy_default.rds")
+    expect_equal_to_reference(lm(dep ~ dummy1(indep)),"rds/lm_dichotomy_default2.rds")
+}
 
 expect_identical(dummy(indep,keep_values=1),structure(c(1, 1, 0, 0, 0, 0), .Dim = c(6L, 1L), .Dimnames = list(
     NULL, "Label|a"), class = c("dichotomy", "matrix")))
@@ -473,7 +517,7 @@ expect_identical(as.dichotomy(dich),
 "data.frame")))
 
 expect_identical(dummy(dich), 
-structure(c(NA, NA, NA), 
+structure(c(NA, NA, NA)*1, 
 .Dim = c(3L, 1L), 
 .Dimnames = list(NULL, 
 "NA"), class = c("dichotomy", "matrix")))
@@ -486,13 +530,13 @@ structure(list(`NA` = c(NA)),
              "data.frame")))
 
 expect_identical(dummy(NA), 
-                 structure(NA, 
+                 structure(NA*1, 
                            .Dim = c(1L, 1L), 
                            .Dimnames = list(NULL, 
 "NA"), class = c("dichotomy", "matrix")))
 
 expect_identical(dummy1(NA), 
-structure(NA, 
+structure(NA*1, 
 .Dim = c(1L, 1L), 
 .Dimnames = list(NULL, 
 "NA"), class = c("dichotomy", "matrix")))
